==> node-bypasser-1.4.0.tgz: package/test/bypass.js <==
/*jshint expr: true*/
var expect = require('chai').expect;

var Bypasser = require('../index.js');

describe('Decrypt', function() {
	this.timeout(0);

	it('Adf.ly', function(done) {
		var b = new Bypasser('http://adf.ly/pVVXg');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('Linkbucks', function(done) {
		var b = new Bypasser('http://www.linkbucks.com/AAqnD');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('Linkbucks (alternate)', function(done) {
		var b = new Bypasser('http://www.zatnawqy.net/AAnqF');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('Generic --> Linkbucks', function(done) {
		var b = new Bypasser('http://www.cash4files.com/AAnqF');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('Shorte.st', function(done) {
		var b = new Bypasser('http://sh.st/gS8XD');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('AdFoc.us', function(done) {
		var b = new Bypasser('http://adfoc.us/x57045654');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('P.pw', function(done) {
		var b = new Bypasser('http://p.pw/bai1hN');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('LinkShrink.net', function(done) {
		var b = new Bypasser('http://linkshrink.net/7znHwW');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('Clk.im', function(done) {
		var b = new Bypasser('http://clk.im/fovq');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('Link5s.com', function(done) {
		var b = new Bypasser('http://link5s.com/Gmq');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('Generic goo.gl', function(done) {
		var b = new Bypasser('http://goo.gl/NWt4Es');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com/');
			done();
		});
	});

	it('Generic custom bit.ly', function(done) {
		var b = new Bypasser('http://l.khoanguyen.me/1HBv4tx');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com/');
			done();
		});
	});

	it('NowVideo', function(done) {
		var b = new Bypasser('http://www.nowvideo.li/video/9f86b7f7f0a31');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result.slice(-4)).to.equal('.mp4');
			done();
		});
	});

	it('AuroraVid', function(done) {
		var b = new Bypasser('http://www.auroravid.to/video/94f6df18e053e');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result.slice(-4)).to.equal('.flv');
			done();
		});
	});

	it('Throw error when receive invalid URL', function(done) {
		var b = new Bypasser('github.com');
		b.decrypt(function(err, result) {
			expect(result).to.be.undefined;
			expect(err).to.equal('This is not a valid url');
			done();
		});
	});

	it('Bc.vc', function(done) {
		var b = new Bypasser('http://bc.vc/Eu0Oiv');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it.skip('Link4ad.net', function(done) {
		var b = new Bypasser('http://link4ad.com/abGaBwGn');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});
});

==> node-bypasser-1.7.0.tgz: package/test/bypass.js <==
/*jshint expr: true*/
var expect = require('chai').expect;

var Bypasser = require('../index.js');

describe('Decrypt', function() {
	this.timeout(0);

	it('Adf.ly', function(done) {
		var b = new Bypasser('http://adf.ly/pVVXg');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('Linkbucks', function(done) {
		var b = new Bypasser('http://www.linkbucks.com/AAqnD');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('Linkbucks (alternate)', function(done) {
		var b = new Bypasser('http://www.zatnawqy.net/AAnqF');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('Generic --> Linkbucks', function(done) {
		var b = new Bypasser('http://www.cash4files.com/AAnqF');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('Shorte.st', function(done) {
		var b = new Bypasser('http://sh.st/gS8XD');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('AdFoc.us', function(done) {
		var b = new Bypasser('http://adfoc.us/x57045654');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('P.pw', function(done) {
		var b = new Bypasser('http://p.pw/bai1hN');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('LinkShrink.net', function(done) {
		var b = new Bypasser('http://linkshrink.net/7bzlRS');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('Link5s.com', function(done) {
		var b = new Bypasser('http://link5s.com/Gmq');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});

	it('Generic goo.gl', function(done) {
		var b = new Bypasser('http://goo.gl/NWt4Es');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com/');
			done();
		});
	});

	it('Generic custom bit.ly', function(done) {
		var b = new Bypasser('http://l.khoanguyen.me/1HBv4tx');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com/');
			done();
		});
	});

	it('NowVideo', function(done) {
		var b = new Bypasser('http://www.nowvideo.li/video/9f86b7f7f0a31');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result.slice(-4)).to.equal('.mp4');
			done();
		});
	});

	it('AuroraVid', function(done) {
		var b = new Bypasser('http://www.auroravid.to/video/94f6df18e053e');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result.slice(-4)).to.equal('.flv');
			done();
		});
	});

	it('Throw error when receive invalid URL', function(done) {
		var b = new Bypasser('github.com');
		b.decrypt(function(err, result) {
			expect(result).to.be.undefined;
			expect(err).to.equal('This is not a valid url');
			done();
		});
	});

	it('Bc.vc', function(done) {
		var b = new Bypasser('http://bc.vc/Eu0Oiv');
		b.decrypt(function(err, result) {
			expect(err).to.be.null;
			expect(result).to.equal('http://github.com');
			done();
		});
	});
});
